Module cfg

Module cfg 

Structs

BranchEdge
Used to represent the opcode that was used for this branch and the block index it’s jumping to. We do this so the value of the branch instruction cannot represent a wrong index.
ControlFlowGraph
ExceptionBlock
Represents an exception block in the control flow graph This includes a list of block indexes that belong to this exception block
NormalBlock
Represents a normal block in the control flow graph

Enums

Block
BlockIndex
BlockIndexInfo

Functions

create_cfg
Exception table should be passed for 3.11+
simple_cfg_to_ext_cfg