pub struct NormalBlock<I: GenericInstruction> {
pub instructions: Vec<I>,
pub branch_block: BlockIndexInfo<<I::Opcode as GenericOpcode>::BranchReason>,
pub default_block: BlockIndexInfo<<I::Opcode as GenericOpcode>::BranchReason>,
}Expand description
Represents a normal block in the control flow graph
Fields
instructions: Vec<I>branch_block: BlockIndexInfo<<I::Opcode as GenericOpcode>::BranchReason>Index to block for conditional jump
default_block: BlockIndexInfo<<I::Opcode as GenericOpcode>::BranchReason>Index to default block (unconditional)
Implementations
Sourceimpl<T: GenericInstruction> NormalBlock<T>
impl<T: GenericInstruction> NormalBlock<T>
pub fn is_terminating(&self) -> bool
Sourcepub fn is_conditional(&self) -> bool
pub fn is_conditional(&self) -> bool
Whether the block has a conditional jump or not