Structs
- Branch
Edge - Used to represent the opcode that was used for this branch and the block index it’s jumping to. We do this so the value of the branch instruction cannot represent a wrong index.
- Control
Flow Graph - Exception
Block - Represents an exception block in the control flow graph This includes a list of block indexes that belong to this exception block
- Normal
Block - Represents a normal block in the control flow graph
Enums
Functions
- create_
cfg - Exception table should be passed for 3.11+
- simple_
cfg_ to_ ext_ cfg